% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/colby_constructors.R
\name{basic_table}
\alias{basic_table}
\title{Layout with 1 column and zero rows}
\usage{
basic_table(
  title = "",
  subtitles = character(),
  main_footer = character(),
  prov_footer = character(),
  show_colcounts = FALSE,
  inset = 0L
)
}
\arguments{
\item{title}{character(1). Main title. Ignored for subtables.}

\item{subtitles}{character. Subtitles. Ignored for subtables.}

\item{main_footer}{character. Main global (non-referential) footer materials.}

\item{prov_footer}{character. Provenance-related global footer materials.
Generally should not be modified by hand.}

\item{show_colcounts}{logical(1). Should column counts be displayed in the
resulting table
when this layout is applied to data}

\item{inset}{numeric(1). Number of spaces to inset the table header, table
body, referential footnotes, and main_footer, as compared to alignment
of title, subtitle, and provenance footer. Defaults to 0 (no inset).}
}
\value{
A \code{PreDataTableLayouts} object suitable for passing to further
layouting functions, and to \code{build_table}.
}
\description{
Every layout must start with a basic table.
}
\examples{

lyt <- basic_table() \%>\%
  analyze("AGE", afun = mean)

build_table(lyt, DM)


lyt <- basic_table(title = "Title of table",
                   subtitles = c("a number", "of subtitles"),
                   main_footer = "test footer",
                   prov_footer = paste("test.R program, executed at",
                                       Sys.time())) \%>\%
  split_cols_by("ARM") \%>\%
  analyze("AGE", mean)

build_table(lyt, DM)

}
